@@ -71,7 +71,7 @@
 
 /* Build against libpng. */
 #ifndef ENABLE_LIBPNG
-#define ENABLE_LIBPNG 1
+/* #undef ENABLE_LIBPNG */
 #endif
 
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
